@@ -13,6 +13,7 @@ use {
         dependency::DependencyList,
         error::{DebianError, Result},
     },
+    chrono::{DateTime, TimeZone, Utc},
     futures::{AsyncBufRead, AsyncBufReadExt},
     pin_project::pin_project,
     std::{
@@ -170,6 +171,13 @@ impl<'a> ControlField<'a> {
         Box::new(self.value.lines().map(|x| x.trim_start()))
     }
 
+    /// Obtain an iterator of comma delimited values in the value.
+    ///
+    /// Whitespace surrounding the comma is trimmed.
+    pub fn iter_comma_delimited(&self) -> Box<(dyn Iterator<Item = &str> + '_)> {
+        Box::new(self.value.as_ref().split(',').map(|v| v.trim()))
+    }
+
     /// Write the contents of this field to a writer.
     pub fn write<W: Write>(&self, writer: &mut W) -> std::io::Result<()> {
         writer.write_all(self.name.as_bytes())?;
@@ -285,6 +293,17 @@ impl<'a> ControlParagraph<'a> {
         self.field_str(name).map(DependencyList::parse)
     }
 
+    /// Obtain the value of a field parsed as an RFC 5322 date string.
+    ///
+    /// This will parse values like `Sat, 09 Oct 2021 09:34:56 UTC`.
+    ///
+    /// The timezone is always normalized to UTC even if it is expressed differently in the
+    /// source string.
+    pub fn field_datetime_rfc5322(&self, name: &str) -> Option<Result<DateTime<Utc>>> {
+        self.field_str(name)
+            .map(|v| Ok(Utc.timestamp(mailparse::dateparse(v)?, 0)))
+    }
+
     /// Obtain the field with the given name as a [ControlFieldValue::Simple], if possible.
     pub fn field_simple(&self, name: &str) -> Option<Result<ControlFieldValue<'a>>> {
         self.field(name).map(|cf| cf.as_simple())
@@ -311,6 +330,14 @@ impl<'a> ControlParagraph<'a> {
         self.field(name).map(|f| f.iter_lines())
     }
 
+    /// Obtain an iterator of comma-delimited values in the named field.
+    pub fn iter_field_comma_delimited(
+        &self,
+        name: &str,
+    ) -> Option<Box<(dyn Iterator<Item = &str> + '_)>> {
+        self.field(name).map(|f| f.iter_comma_delimited())
+    }
+
     /// Convert this paragraph to a [HashMap].
     ///
     /// Values will be the string normalization of the field value, including newlines and
