@@ -5,7 +5,10 @@
 /*! I/O helpers. */
 
 use {
-    crate::{error::Result, pgp::MyHasher, repository::release::ChecksumType},
+    crate::{
+        error::{DebianError, Result},
+        repository::release::ChecksumType,
+    },
     async_compression::futures::bufread::{
         BzDecoder, BzEncoder, GzipDecoder, GzipEncoder, LzmaDecoder, LzmaEncoder, XzDecoder,
         XzEncoder,
@@ -13,6 +16,7 @@ use {
     async_trait::async_trait,
     futures::{AsyncBufRead, AsyncRead, AsyncWrite},
     pgp::crypto::Hasher,
+    pgp_cleartext::CleartextHasher,
     pin_project::pin_project,
     std::{
         collections::HashMap,
@@ -23,7 +27,7 @@ use {
 };
 
 /// Represents a content digest.
-#[derive(Clone, Eq, PartialEq)]
+#[derive(Clone, Eq, PartialEq, PartialOrd)]
 pub enum ContentDigest {
     /// An MD5 digest.
     Md5(Vec<u8>),
@@ -44,9 +48,25 @@ impl std::fmt::Debug for ContentDigest {
 }
 
 impl ContentDigest {
+    /// Create a new MD5 instance by parsing a hex digest.
+    pub fn md5_hex(digest: &str) -> Result<Self> {
+        Self::from_hex_digest(ChecksumType::Md5, digest)
+    }
+
+    /// Create a new SHA-1 instance by parsing a hex digest.
+    pub fn sha1_hex(digest: &str) -> Result<Self> {
+        Self::from_hex_digest(ChecksumType::Sha1, digest)
+    }
+
+    /// Create a new SHA-256 instance by parsing a hex digest.
+    pub fn sha256_hex(digest: &str) -> Result<Self> {
+        Self::from_hex_digest(ChecksumType::Sha256, digest)
+    }
+
     /// Obtain an instance by parsing a hex string as a [ChecksumType].
-    pub fn from_hex_checksum(checksum: ChecksumType, digest: &str) -> Result<Self> {
-        let digest = hex::decode(digest)?;
+    pub fn from_hex_digest(checksum: ChecksumType, digest: &str) -> Result<Self> {
+        let digest = hex::decode(digest)
+            .map_err(|e| DebianError::ContentDigestBadHex(digest.to_string(), e))?;
 
         Ok(match checksum {
             ChecksumType::Md5 => Self::Md5(digest),
@@ -58,9 +78,9 @@ impl ContentDigest {
     /// Create a new hasher matching for the type of this digest.
     pub fn new_hasher(&self) -> Box<dyn Hasher + Send> {
         Box::new(match self {
-            Self::Md5(_) => MyHasher::md5(),
-            Self::Sha1(_) => MyHasher::sha1(),
-            Self::Sha256(_) => MyHasher::sha256(),
+            Self::Md5(_) => CleartextHasher::md5(),
+            Self::Sha1(_) => CleartextHasher::sha1(),
+            Self::Sha256(_) => CleartextHasher::sha256(),
         })
     }
 
@@ -298,9 +318,9 @@ pub struct MultiDigester {
 impl Default for MultiDigester {
     fn default() -> Self {
         Self {
-            md5: Box::new(MyHasher::md5()),
-            sha1: Box::new(MyHasher::sha1()),
-            sha256: Box::new(MyHasher::sha256()),
+            md5: Box::new(CleartextHasher::md5()),
+            sha1: Box::new(CleartextHasher::sha1()),
+            sha256: Box::new(CleartextHasher::sha256()),
         }
     }
 }
@@ -444,7 +464,7 @@ pub trait DataResolver: Sync {
     ///
     /// This obtains a reader for path data and returns the raw data without any
     /// decoding applied.
-    async fn get_path(&self, path: &str) -> Result<Pin<Box<dyn AsyncBufRead + Send>>>;
+    async fn get_path(&self, path: &str) -> Result<Pin<Box<dyn AsyncRead + Send>>>;
 
     /// Obtain a reader that performs content integrity checking.
     ///
@@ -474,7 +494,11 @@ pub trait DataResolver: Sync {
         path: &str,
         compression: Compression,
     ) -> Result<Pin<Box<dyn AsyncRead + Send>>> {
-        read_decompressed(self.get_path(path).await?, compression).await
+        read_decompressed(
+            Box::pin(futures::io::BufReader::new(self.get_path(path).await?)),
+            compression,
+        )
+        .await
     }
 
     /// Like [Self::get_path_decoded()] but also perform content integrity verification.
@@ -521,7 +545,7 @@ impl<R: DataResolver + Send> PathMappingDataResolver<R> {
 
 #[async_trait]
 impl<R: DataResolver + Send> DataResolver for PathMappingDataResolver<R> {
-    async fn get_path(&self, path: &str) -> Result<Pin<Box<dyn AsyncBufRead + Send>>> {
+    async fn get_path(&self, path: &str) -> Result<Pin<Box<dyn AsyncRead + Send>>> {
         self.source
             .get_path(self.path_map.get(path).map(|s| s.as_str()).unwrap_or(path))
             .await
