@@ -19,15 +19,15 @@ use {
         deb::reader::resolve_control_file,
         error::{DebianError, Result},
         io::{read_compressed, ContentDigest, DataResolver, MultiContentDigest, MultiDigester},
-        pgp::cleartext_sign,
         repository::{
             release::{ChecksumType, ReleaseFile, DATE_FORMAT},
-            Compression, RepositoryPathVerificationState, RepositoryWriter,
+            Compression, PublishEvent, RepositoryPathVerificationState, RepositoryWriter,
         },
     },
     chrono::{DateTime, Utc},
     futures::{AsyncRead, AsyncReadExt, StreamExt, TryStreamExt},
     pgp::{crypto::HashAlgorithm, types::SecretKeyTrait},
+    pgp_cleartext::cleartext_sign,
     std::{
         borrow::Cow,
         collections::{BTreeMap, BTreeSet, HashMap},
@@ -196,57 +196,6 @@ pub struct BinaryPackagePoolArtifact<'a> {
     pub digest: ContentDigest,
 }
 
-/// Represents a publishing event.
-pub enum PublishEvent {
-    ResolvedPoolArtifacts(usize),
-
-    /// A pool artifact with the given path is current and was not updated.
-    PoolArtifactCurrent(String),
-
-    /// A pool artifact with the given path is missing and will be created.
-    PoolArtifactMissing(String),
-
-    /// Total number of pool artifacts to publish.
-    PoolArtifactsToPublish(usize),
-
-    /// A pool artifact with the given path and size was created.
-    PoolArtifactCreated(String, u64),
-
-    /// The path to an index file to write.
-    IndexFileToWrite(String),
-
-    /// An index file that was written.
-    IndexFileWritten(String, u64),
-}
-
-impl std::fmt::Display for PublishEvent {
-    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        match self {
-            Self::ResolvedPoolArtifacts(count) => {
-                write!(f, "resolved {} needed pool artifacts", count)
-            }
-            Self::PoolArtifactCurrent(path) => {
-                write!(f, "pool path {} is present", path)
-            }
-            Self::PoolArtifactMissing(path) => {
-                write!(f, "pool path {} will be written", path)
-            }
-            Self::PoolArtifactsToPublish(count) => {
-                write!(f, "{} pool artifacts will be written", count)
-            }
-            Self::PoolArtifactCreated(path, size) => {
-                write!(f, "wrote {} bytes to {}", size, path)
-            }
-            Self::IndexFileToWrite(path) => {
-                write!(f, "index file {} will be written", path)
-            }
-            Self::IndexFileWritten(path, size) => {
-                write!(f, "wrote {} bytes to {}", size, path)
-            }
-        }
-    }
-}
-
 // (Package, Version) -> paragraph.
 type IndexedBinaryPackages<'a> = BTreeMap<(String, String), ControlParagraph<'a>>;
 
@@ -522,7 +471,7 @@ impl<'cf> RepositoryBuilder<'cf> {
         // Different packages have different fields and it is effectively impossible to maintain
         // an numeration of all known fields. So, copy over all fields and ignore the special ones,
         // which we handle later.
-        for field in original_control_file.as_ref().iter_fields() {
+        for field in original_control_file.iter_fields() {
             if ![
                 "Description",
                 "Filename",
@@ -540,7 +489,7 @@ impl<'cf> RepositoryBuilder<'cf> {
         // The `Description` field is a bit wonky in Packages files. Instead of capturing multiline
         // values, `Description` is just the first line and a `Description-md5` contains the md5
         // of the multiline value.
-        if let Some(description) = original_control_file.as_ref().field("Description") {
+        if let Some(description) = original_control_file.field("Description") {
             let description = description.value_str();
 
             if let Some(index) = description.find('\n') {
@@ -647,7 +596,7 @@ impl<'cf> RepositoryBuilder<'cf> {
                 let digest_hex = para
                     .field_str(strongest_checksum.field_name())
                     .expect("checksum's field should have been set");
-                let digest = ContentDigest::from_hex_checksum(*strongest_checksum, digest_hex)?;
+                let digest = ContentDigest::from_hex_digest(*strongest_checksum, digest_hex)?;
 
                 Ok(BinaryPackagePoolArtifact { path, size, digest })
             })
@@ -1052,9 +1001,7 @@ impl<'cf> RepositoryBuilder<'cf> {
         let release_write = writer
             .write_path(
                 release_path.into(),
-                Box::pin(futures::io::Cursor::new(
-                    release.as_ref().to_string().into_bytes(),
-                )),
+                Box::pin(futures::io::Cursor::new(release.to_string().into_bytes())),
             )
             .await?;
 
@@ -1070,7 +1017,7 @@ impl<'cf> RepositoryBuilder<'cf> {
                 key,
                 password,
                 HashAlgorithm::SHA2_256,
-                std::io::Cursor::new(release.as_ref().to_string().as_bytes()),
+                std::io::Cursor::new(release.to_string().as_bytes()),
             )?;
 
             if let Some(cb) = progress_cb {
@@ -1163,7 +1110,6 @@ async fn get_path_and_copy<'a, 'b>(
 
 #[cfg(test)]
 mod test {
-
     use {
         super::*,
         crate::{
@@ -1275,7 +1221,7 @@ mod test {
         {
             let dest_filename = builder.add_binary_deb("main", package)?;
 
-            let source_filename = package.as_ref().field_str("Filename").unwrap();
+            let source_filename = package.field_str("Filename").unwrap();
 
             mapping_resolver.add_path_map(dest_filename, source_filename);
         }
